@@ -34,13 +34,19 @@ class Client(ABC):
         job = Job('dms.GetObjectTypeByID', Flags=0, ObjectID=object_id)
         return self.execute(job).values['ObjectType']
 
-    def store_in_cache(self, object_id:int, object_type_id:Optional[int]=None, checkout:Optional[bool]=False) -> List[ResultFile]:
+
+    def store_in_cache(self, object_id:int, object_type_id:int=None, checkout:bool=False) -> List[ResultFile]:
         """Helper function: Execute the std.StoreInCache job for a given object to retrieve its files.
 
-        Keyword arguments:
-        object_id -- A document id.
-        object_type_id -- (Optional) The documents type id. When not provided, it is retrieve via get_object_type_by_id() first.
-        checkout -- (Optional) When True, change the documents state to checked out on the server.
+        ### Keyword arguments:
+
+        - object_id -- A document id.
+        - object_type_id -- (Optional) The documents type id. When not provided, it is retrieve via get_object_type_by_id() first.
+        - checkout -- (Optional) When True, change the documents state to checked out on the server.
+
+        ### Warning
+
+        Known bug: Throws an enaio error on archived documents. 
         """
         if object_type_id == None:
             object_type_id = self.get_object_type_by_id(object_id)
@@ -58,6 +64,32 @@ class Client(ABC):
 
         return result.files
 
+
+    def store_in_cache_by_id(
+        self, object_id:int, convert:StoreInCacheByIdConversion=StoreInCacheByIdConversion.NONE) -> List[ResultFile]:
+        """Helper function: Execute the std.StoreInCacheById job for a given object to retrieve/convert its files.
+
+        ### Keyword arguments:
+
+        - object_id -- A document id.
+        - convert -- (Optional) Convert 
+           - main type 1, 2, 3 or 4 to PDF with StoreInCacheByIdConversion.PDF 
+           - main type 2 or 3 with StoreInCacheByIdConversion.MULTIPAGE_TIFF
+        """
+
+        job = Job('std.StoreInCacheById',
+            Flags=1,
+            dwObjectID=object_id,
+            Convert=convert.value
+        )
+
+        result = self.execute(job)
+        if result.return_code != 0:
+            raise(RuntimeError(f'Received return code {result.return_code}: {result.error_message}'))
+
+        return result.files
+
+
     def xml_import(self,
                   object_name:str,
                   search_fields:Dict[str, str],
